# fwdpp to-do list

* Ability to initialize a population from a list of gametes.
* Re-organize unit tests with subdirectories (fwdpp, extensions, internal, sugar, etc.)
* Remove all unit test blocks that are only API tests.  DONE (where it makes sense)
* Add unit tests for fwdpp/util.hpp. DONE (recycling_integration.cc)
* Improve unit test coverage for main library sampling functions
* Improve unit test coverage for sugar layer sampling functions
* Write unit tests for fwdpp/internal/recycling.hpp.  DONE (recycling_integration.cc)
* Write unit tests making sure that fwdpp/internal/recycling.hpp and fwdpp/util.hpp work togeter. DONE.
* Improve C++14-like parts of fwdpp/type_traits.hpp.  Some of what is there can be re-written as template aliases. DONE.
* Document concept of recycling
* 